# Single-cell multimodal modeling with deep parametric inference
The proliferation of single-cell multimodal sequencing technologies has enabled us to understand cellular heterogeneity with multiple views, providing novel and actionable biological insights into the disease-driving mechanisms. Here, we propose the deep parametric inference (DPI) model, an end-to-end framework for single-cell multimodal data analysis. At the heart of DPI is the multimodal parameter space, where the parameters from each modal are inferred by neural networks. 
The dpi framework works with scanpy and supports the following single-cell multimodal analyses:
* Multimodal data integration
* Multimodal data noise reduction
* Cell clustering and visualization
* Reference and query cell types
* Cell state vector field visualization